/*
 * Copyright (C) 2006  Chris Rose
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 */

package com.aimedia.azjabber.config;

import java.util.Arrays;

import org.jivesoftware.smack.ConnectionConfiguration;

public class JabberConnectionParameters {

    private ConnectionConfiguration connectionConfiguration;

    protected String                username;

    protected byte[]                password;

    protected String                resourceBase;

    public JabberConnectionParameters (String host, int port, String service, String username, byte[] password,
            String resourceBase) {
        this.connectionConfiguration = new ConnectionConfiguration (host, port, service);
        this.username = username;
        this.password = password;
        this.resourceBase = resourceBase;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#hashCode()
     */
    @Override
    public int hashCode () {
        final int PRIME = 31;
        int result = 1;
        result = PRIME * result + ((connectionConfiguration == null) ? 0 : connectionConfiguration.hashCode ());
        result = PRIME * result + Arrays.hashCode (password);
        result = PRIME * result + ((resourceBase == null) ? 0 : resourceBase.hashCode ());
        result = PRIME * result + ((username == null) ? 0 : username.hashCode ());
        return result;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    @Override
    public boolean equals (Object obj) {
        if (this == obj) return true;
        if (obj == null) return false;
        if (getClass () != obj.getClass ()) return false;
        final JabberConnectionParameters other = (JabberConnectionParameters) obj;
        if (connectionConfiguration == null) {
            if (other.connectionConfiguration != null) return false;
        }
        else {
            if (connectionConfiguration.getHost () == null) {
                if (other.connectionConfiguration.getHost () != null) return false;
            }
            else if (!connectionConfiguration.getHost ().equals (other.connectionConfiguration.getHost ()))
                return false;
            if (connectionConfiguration.getServiceName () == null) {
                if (other.connectionConfiguration.getServiceName () != null) return false;
            }
            else if (!connectionConfiguration.getServiceName ()
                    .equals (other.connectionConfiguration.getServiceName ())) return false;
            if (connectionConfiguration.getPort () != other.connectionConfiguration.getPort ()) return false;
        }
        if (!Arrays.equals (password, other.password)) return false;
        if (resourceBase == null) {
            if (other.resourceBase != null) return false;
        }
        else if (!resourceBase.equals (other.resourceBase)) return false;
        if (username == null) {
            if (other.username != null) return false;
        }
        else if (!username.equals (other.username)) return false;
        return true;
    }

    /**
     * @return the host
     */
    public String getHost () {
        return connectionConfiguration.getHost ();
    }

    /**
     * @return the password
     */
    public byte[] getPassword () {
        return password;
    }

    /**
     * @return the port
     */
    public int getPort () {
        return connectionConfiguration.getPort ();
    }

    /**
     * @return the resourceBase
     */
    public String getResourceBase () {
        return resourceBase;
    }

    /**
     * @return the service
     */
    public String getService () {
        return connectionConfiguration.getServiceName ();
    }

    /**
     * @return the username
     */
    public String getUsername () {
        return username;
    }

    public ConnectionConfiguration getConnectionConfiguration () {
        return connectionConfiguration;
    }

}